==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/Input/mpc/translations/mpc_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>DecoderMPCFactory</name>
    <message>
        <location filename="../decodermpcfactory.cpp" line="47"/>
        <source>Musepack Plugin</source>
        <translation>Musepack 插件</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="49"/>
        <source>Musepack Files</source>
        <translation>Musepack 檔案</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="109"/>
        <source>About Musepack Audio Plugin</source>
        <translation>關於 Musepack 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="110"/>
        <source>Qmmp Musepack Audio Plugin</source>
        <translation>Qmmp Musepack 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="111"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MPCMetaDataModel</name>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="46"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Sample rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Hz</source>
        <translation type="unfinished">Hz</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="48"/>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>kbps</source>
        <translation type="unfinished">kbps</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>KB</source>
        <translation type="unfinished">KB</translation>
    </message>
</context>
</TS>

==> qmmp_0.5.4.orig.tar.gz: qmmp-0.5.4/src/plugins/Input/mpc/translations/mpc_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>DecoderMPCFactory</name>
    <message>
        <location filename="../decodermpcfactory.cpp" line="47"/>
        <source>Musepack Plugin</source>
        <translation>Musepack 插件</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="49"/>
        <source>Musepack Files</source>
        <translation>Musepack 檔案</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="109"/>
        <source>About Musepack Audio Plugin</source>
        <translation>關於 Musepack 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="110"/>
        <source>Qmmp Musepack Audio Plugin</source>
        <translation>Qmmp Musepack 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="111"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MPCMetaDataModel</name>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="46"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Sample rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Hz</source>
        <translation type="unfinished">Hz</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="48"/>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>kbps</source>
        <translation type="unfinished">kbps</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>KB</source>
        <translation type="unfinished">KB</translation>
    </message>
</context>
</TS>
